#
# spec file for package dumpvdl2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dumpvdl2
Version:        1.7.1
Release:        lp152.1.3
Summary:        A VDL Mode 2 message decoder and protocol analyzer
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/szpajder/dumpvdl2
#Git-Clone:     https://github.com/szpajder/dumpvdl2.git
Source:         https://github.com/szpajder/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SoapySDR)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libacars) >= 1.3.0
BuildRequires:  pkgconfig(librtlsdr)

%description
A VDL Mode 2 message decoder and protocol analyzer.

Features:
 * Supports following SDR hardware:
   - RTLSDR (via rtl-sdr library)
   - Mirics SDR (via libmirisdr-4)
   - reads prerecorded IQ data from file
 * Decodes up to 8 VDL2 channels simultaneously
 * Outputs messages to standard output or to a file (with optional daily
   or hourly file rotation)
 * Outputs ACARS messages to PlanePlotter over UDP/IP socket
 * Supports message filtering by type or direction (uplink, downlink)
 * Outputs decoding statistics using Etsy StatsD protocol

%prep
%setup -q

%build
%cmake \
    -DRTLSDR=ON \
    -DSOAPYSDR=ON \
    -DMIRISDR=OFF \
    -DSDRPLAY=OFF \
    -DETSY_STATSD=OFF
%make_jobs

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%{_bindir}/dumpvdl2

%changelog
* Mon Nov 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.1
  * Fixed an issue where a truncated or corrupted ICAO APDU could
    cause a crash in ASN.1 decoder.
  * Fixed an issue where NULL characters in XID attribute values
    could cause them do be printed partially. Any non-printable
    characters in octet strings printed as text are now replaced
    with periods.
* Mon Aug 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.0
  * Complete overhaul of output generation code.
  * Significant enhancements to CLNP, COTP and IDRP decoders.
    Most if not all protocol headers are now decoded and included
    in the output.
  * Added a decoder for X.225 Session Protocol SPDUs.
  * Added a decoder for VDL SNDCF error reports.
  * XID: improved decoding of XID sequencing, Frequency support
    and System mask attributes.
  * X.25: improved decoding of facility fields, call clearing
    causes and diagnostic codes.
  * Minor bug fixes.
* Fri Jan 18 2019 mardnh@gmx.de
- Update to version 1.6.0
  * New build system based on cmake.
  * FANS/1-A CPDLC, ADS-C and ACARS decoders have been removed.
    These features have been moved to libacars library, which is
    now a mandatory dependency
  * Added support for SoapySDR library. However there are still
    some limitations with respect to SDR types which dumpvdl2
    can work with. As of now, the device must support a sampling
    rate of 2100000 samples per second. This will be addressed in
    a future release.
  * Minor bugfixes
* Sun Nov 18 2018 mardnh@gmx.de
- Update to version 1.5.0
  * Sync with the latest SDRPlay API v. 2.13 which is now required
    to compile the program.
  * Added support for SDRPlay RSPduo (with tuner selection, bias-T
    and notch filters).
  * Added support for RSP1A features: Bias-T and broadcast notch
    filter.
  * Minor bugfixes
* Wed Aug  1 2018 mardnh@gmx.de
- Update to version 1.4.0
  * Major improvements to the DSP and decoding engine - gives much
    better decoding success rate, especially for weak transmissions
    from distant aircraft.
  * Each VDL2 channel is now processed in a separate thread, which
    allows balancing the load onto multiple CPU cores.
  * Fixed a nasty decoder bug which caused good frames to be
    corrupted during decoding stage and therefore missed.
  * Added CRC checking for ACARS messages. If there is a CRC
    mismatch, the message will still be logged, but with an
    appropriate warning.
  * New StatsD metric avlc.msg.air2air - counts messages from
    aircraft to aircraft (however strange it seems, such things
    happen in real life).
  * New StatsD metric decoder.errors.too_long - counts VDL2 bursts
    dropped due to unreasonably large value in the length field.
  * Due to changes in the decoding engine, the following StatsD
    metric are now obsolete and have been removed:
    avlc.errors.no_flag_start, avlc.errors.no_flag_end,
    decoder.errors.no_preamble.
  * Added --extended-header command line option which causes a few
    decoder diagnostic parameters to be logged for each message.
    Refer to the FAQ in README.md for description of the fields.
  * Other minor bugfixes and improvements.
  * C11-capable compiler is now required to build the program.
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 1.3.1
  * Added decpdlc utility which decodes FANS-1/A CPDLC messages
    supplied from command line or from a file. Can be used to
    decode CPDLC traffic received via other media than VDL-2
    (eg. ACARS, HFDL, SATCOM). Refer to "decpdlc" section in
    README.md for details
* Wed Apr 11 2018 mardnh@gmx.de
- Update to version 1.3.0
  * Added decoder for FANS-1/A ADS-C messages
  * Added decoder for FANS-1/A CPDLC messages
  * Human-readable formatting of CPDLC and Context Management
    messages (if you still want the old format, add --dump-asn1
    command line option)
  * Added install rule to Makefile
  * Added a sample systemd service file
  * Bug fixes
* Mon Jan  1 2018 mardnh@gmx.de
- Update to version 1.2.0
  * Better input signal filtering - reduced bit error rate, 10-50%% more
    messages successfully decoded.
  * SDRPlay: major bugfixes in sample buffer handling code - shall now
    perform equally well as RTLSDR (or even better).
  * SDRPlay: --gain knob replaced with --gr (gain reduction). This makes
    gain configuration in dumpvdl2 compatible with other SDRPlay apps.
    See README.md for details.
  * SDRPlay: support for selecting device by serial number.
    Added optional build-time PLATFORM knob which sets CPU-specific
  * compiler flags to optimize the code for various flavours of
    Raspberry Pi. Supported values: rpiv1, rpiv2, rpiv3.
  * Other minor bug fixes
- Remove patch:
  * dumpvdl2-obey-cflags.diff
* Wed Jun 28 2017 jengelh@inai.de
- Remove disputable/irrelevant wording from description.
* Tue Jun 20 2017 mardnh@gmx.de
- Update to version 1.1.0
  * Support for SDRPlay RSP1 and 2 using native binary API
  * Added dissector for ISO 8073/X.224 Connection-oriented Transport Protocol
  * Added dissectors for ICAO Context Management and CPDLC
  * Enhancements for ES-IS and XID dissectors
  * Support for referring to dongles using their serial numbers
  * Output formatting fixes
  * Bug fixes
- Rebase patch:
  * dumpvdl2-obey-cflags.diff
* Tue Jun 20 2017 mpluskal@suse.com
- Tiny packaging cleanup
* Mon Feb 27 2017 mardnh@gmx.de
- initial package
